<?php
/**
 * NORD functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package NORD
 */

if ( ! defined( 'ABSPATH' ) ) exit;

define( 'NORD', wp_get_theme()->get( 'Name' ));
define( 'NORD_VER', wp_get_theme()->get( 'Version' ));
define( "NORD_THEME_ROOT", get_template_directory_uri() );
define( "NORD_CSS",get_template_directory_uri() . "/assets/css/" );
define( "NORD_JS",get_template_directory_uri() . "/assets/js/" );
define( "NORD_PATH", get_template_directory_uri() );


if ( ! function_exists( 'nord_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function nord_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on NORD, use a find and replace
	 * to change 'nord' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'nord', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	add_image_size( 'nord-thumbs-gallery', '475', '310', true );
	add_image_size( 'nord_team_thumb', '600', '410', true );
	add_image_size( 'nord-portfolio-gallery', '1170', '700', true );


	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Main Menu', 'nord' ),
	) );

/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array( 'aside', 'image', 'quote', 'link', 'gallery', 'audio') );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'nord_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif;
add_action( 'after_setup_theme', 'nord_setup' );


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function nord_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'nord_content_width', 640 );
}
add_action( 'after_setup_theme', 'nord_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function nord_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Blog Sidebar', 'nord' ),
		'id'            => 'blog-sidebar',
		'description'   => esc_html__( 'Add Blog widgets here.', 'nord' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );	
}
add_action( 'widgets_init', 'nord_widgets_init' );



function nord_google_fonts_url() {
    $font_url = '';   
    if ( 'off' !== _x( 'on', 'Google font: on or off', 'nord' ) ) {
        $font_url = add_query_arg( 'family', urlencode( 'Droid Serif:400,400italic,700,700italic|Open Sans:400,700' ), "//fonts.googleapis.com/css" );
    }
    return $font_url;
}


/**
 * Enqueue scripts and styles.
 */
function nord_scripts() {
	
	//CSS
	wp_enqueue_style( 'nord-google-fons', nord_google_fonts_url() );
	wp_enqueue_style( 'bootstrap', NORD_CSS . "bootstrap.css" );
	wp_enqueue_style( 'nord-elements', NORD_CSS . "elements.css" );
	wp_enqueue_style( 'nord-featured', NORD_CSS . "featured.css" );
	wp_enqueue_style( 'ionicons.min', NORD_CSS . "ionicons.min.css" );
	wp_enqueue_style( 'webfonts', NORD_THEME_ROOT . "/assets/fonts/webfonts.css" );
	
	wp_enqueue_style( 'isotope',NORD_CSS . "isotope.css" );
	wp_enqueue_style( 'nord-main',NORD_CSS . "main.css" );
	wp_enqueue_style( 'nord-main-bg',NORD_CSS . "main-bg.css" );
	wp_enqueue_style( 'nord-main-responsive',NORD_CSS . "main-responsive.css" );
	wp_enqueue_style( 'owl.carousel',NORD_CSS . "owl.carousel.css" );
	wp_enqueue_style( 'animate.min',NORD_CSS . "animate.min.css" );
	wp_enqueue_style( 'sinister',NORD_CSS . "sinister.css" );
	wp_enqueue_style( 'umbg',NORD_CSS . "umbg.css" );
	wp_enqueue_style( 'venobox',NORD_CSS . "venobox.css" );	
	wp_enqueue_style( 'nord-style', get_stylesheet_uri() );


	// JS
	wp_enqueue_script( 'bootstrap.min', NORD_JS . "bootstrap.min.js", array('jquery'), '', true );
	wp_enqueue_script( 'nord-common', NORD_JS . "common.js", array('jquery'), '', true );
	wp_enqueue_script( 'isotope', NORD_JS . "isotope.js", array('jquery'), '', true );
	wp_enqueue_script( 'venobox.min', NORD_JS . "venobox.min.js", array('jquery'), '', true );
	wp_enqueue_script( 'elements', NORD_JS . "elements.js", array('jquery'), '', true );
	wp_enqueue_script( 'nord-main', NORD_JS . "main.js", array('jquery'), '', true );
	
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'nord_scripts' );


/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';


require get_template_directory() . '/inc/theme-functions.php';

require get_template_directory() . '/inc/wp_bootstrap_nav_walker.php';


// Include the meta box script
require_once ( get_template_directory().'/lib/metabox.php' );

// Ionicons
require_once ( get_template_directory().'/inc/icons-ionicons.php' );


/*-------------------------------------------------------
*			Include the TGM Plugin Activation class
*-------------------------------------------------------*/

require_once( get_template_directory()  . '/inc/class-tgm-plugin-activation.php');

// Load theme version of redux if plugin isn't activated
require_once( get_template_directory() . '/admin/admin.php');


/**
 * TGMA
 */
add_action( 'tgmpa_register', 'nord_register_required_plugins' );

function nord_register_required_plugins() {

    /**
     * Array of plugin arrays. Required keys are name, slug and required.
     * If the source is NOT from the .org repo, then source is also required.
     */


    $plugins = array(

        // This is an example of how to include a plugin pre-packaged with a theme
    	array(
    		 	'name'     			 => esc_html__( 'Candor Framework', 'nord' ),
    			'slug'     			 => esc_html__( 'candor-framework', 'nord' ),
    			'source'   			 => esc_url_raw( 'https://github.com/jeweltheme/candor-framework/archive/master.zip','nord' ),
    			'required' 			 => true,
    			'version'            => '1.2.5'
    		),	
    	array(
	    		'name'     			 => esc_html__( 'Visual Composer', 'nord' ),
	    		'slug'     			 => esc_html__( 'js_composer', 'nord' ),
	    		'source'   			 => esc_url_raw( 'http://demos.jeweltheme.com/plugin-downloads/js_composer.zip' ),
	    		'required' 			 => true,
	    		'version' 			 => '5.1.1',
    		),
    	array(
    		 	'name'     			 => esc_html__( 'Revolution Slider', 'nord' ),
    			'slug'     			 => esc_html__( 'revslider', 'nord' ),
    			'source'   			 => esc_url_raw( 'http://demos.jeweltheme.com/plugin-downloads/revslider.zip','nord' ),
    			'required' 			 => true,
    			'version'            => '5.4'
    		),	    	
    	array(
    		 	'name'     			 => esc_html__( 'WP Subtitle', 'nord' ),
    			'slug'     			 => esc_html__( 'wp-subtitle', 'nord' ),
    			'required' 			 => true,
    			'version'            => ''
    		),	
        array(
	        	'name'      		 => esc_html__( 'Contact Form 7', 'nord' ),
	        	'slug'      		 => esc_html__( 'contact-form-7', 'nord' ),
	        	'required'  		 => true,
	        	'force_activation'   => false,
	        ),             
        array(
	        	'name'      		 => esc_html__( 'Redux Framework', 'nord' ),
	        	'slug'      		 => esc_html__( 'redux-framework', 'nord' ),
	        	'required'  		 => true,
	        	'force_activation'   => false,
	        ),           
        array(
	        	'name'      		 => esc_html__( 'MailChimp for WordPress', 'nord' ),
	        	'slug'      		 => esc_html__( 'mailchimp-for-wp', 'nord' ),
	        	'required'  		 => true,
	        	'force_activation'   => false,
	        ),           

    );


    /**
     * Array of configuration settings. Amend each line as needed.
     * If you want the default strings to be available under your own theme domain,
     * leave the strings uncommented.
     * Some of the strings are added into a sprintf, so see the comments at the
     * end of each line for what each argument will be.
     */
    $config = array(
        'domain'            => 'nord',           // Text domain - likely want to be the same as your theme.
        'default_path'      => '',                           // Default absolute path to pre-packaged plugins
        'parent_menu_slug'  => 'themes.php',         // Default parent menu slug
        'parent_url_slug'   => 'themes.php',         // Default parent URL slug
        'menu'              => 'install-required-plugins',   // Menu slug
        'has_notices'       => true,                         // Show admin notices or not
        'is_automatic'      => true,            // Automatically activate plugins after installation or not
        'message'           => '',               // Message to output right before the plugins table
        'strings'           => array(
            'page_title'                                => esc_html__( 'Install Required Plugins', 'nord' ),
            'menu_title'                                => esc_html__( 'Install Plugins', 'nord' ),
            'installing'                                => esc_html__( 'Installing Plugin: %s', 'nord' ), // %1$s = plugin name
            'oops'                                      => esc_html__( 'Something went wrong with the plugin API.', 'nord' ),
            'notice_can_install_required'               => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.' ,'nord' ), // %1$s = plugin name(s)
            'notice_can_install_recommended'            => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.','nord' ), // %1$s = plugin name(s)
            'notice_cannot_install'                     => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.','nord' ), // %1$s = plugin name(s)
            'notice_can_activate_required'              => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.','nord' ), // %1$s = plugin name(s)
            'notice_can_activate_recommended'           => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.','nord' ), // %1$s = plugin name(s)
            'notice_cannot_activate'                    => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.','nord' ), // %1$s = plugin name(s)
            'notice_ask_to_update'                      => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.','nord' ), // %1$s = plugin name(s)
            'notice_cannot_update'                      => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.','nord' ), // %1$s = plugin name(s)
            'install_link'                              => _n_noop( 'Begin installing plugin', 'Begin installing plugins', 'nord' ),
            'activate_link'                             => _n_noop( 'Activate installed plugin', 'Activate installed plugins', 'nord' ),
            'return'                                    => esc_html__( 'Return to Required Plugins Installer', 'nord' ),
            'plugin_activated'                          => esc_html__( 'Plugin activated successfully.', 'nord' ),
            'complete'                                  => esc_html__( 'All plugins installed and activated successfully. %s', 'nord' ) // %1$s = dashboard link
        )
    );

    tgmpa( $plugins, $config );

}



/**
 * If visual composer is installed, grab all required files.
 * Wrapped in an if statement so that we can save parsing this if visual composer is not used.
 * It's a speed boost basically.
 */
if( function_exists('vc_set_as_theme') ){
	require get_template_directory() . '/vc_init.php';
}



/**
 * Init theme options
 * Certain theme options need to be written to the database as soon as the theme is installed.
 * This is either for the enqueues in candor-framework, or to override the default image sizes in WooCommerce.
 * Either way this function is only called when the theme is first activated, de-activating and re-activating the theme will result in these options returning to defaults.
 * 
 * @since 1.0.0
 * @author Jewel Theme
 */
if(!( function_exists('nord_init_theme_options') )){
	/**
	 * Hook in on activation
	 */
	global $pagenow;
	
	/**
	 * Define image sizes
	 */
	function nord_init_theme_options() {
		
		//Candor Framework Options

		$framework_args = array(
			'portfolio_post_type'   => '1',
			'rwmbmetabox'           => '1',
			'team_post_type'        => '1',
			'pricing_post_type'     => '1',

			'nord_widgets'     		=> '1',
			'nord_vc_blocks'   		=> '1',
			'nord_shortcodes'  		=> '1',
		);
		update_option('candor_framework_options', $framework_args);
	}
	
	/**
	 * Only call this action when we first activate the theme.
	 */
	if ( 
		is_admin() && isset( $_GET['activated'] ) && $pagenow == 'themes.php' ||
		is_admin() && isset( $_GET['theme'] ) && $pagenow == 'customize.php'
	){
		add_action( 'init', 'nord_init_theme_options', 1 );
	}
}




function nord_removeDemoModeLink() { // Be sure to rename this function to something more unique
    if ( class_exists('ReduxFrameworkPlugin') ) {
        remove_filter( 'plugin_row_meta', array( ReduxFrameworkPlugin::get_instance(), 'plugin_metalinks'), null, 2 );
    }
    if ( class_exists('ReduxFrameworkPlugin') ) {
        remove_action('admin_notices', array( ReduxFrameworkPlugin::get_instance(), 'admin_notices' ) );    
    }
}
add_action('init', 'nord_removeDemoModeLink');



/**
 * Load Theme Support on Init
 */
if(!( function_exists('nord_add_editor_styles') )){
	function nord_add_editor_styles() {
		/**
		 * Add WP Editor Styling
		 */
	    add_editor_style( 'inc/editor-style.css' );
	    
		/**
		 * Set the content width in pixels, based on the theme's design and stylesheet.
		 *
		 * Priority 0 to make it available to lower priority callbacks.
		 *
		 * @global int $content_width
		 */
	    global $content_width;
	    if ( ! isset( $content_width ) ) $content_width = 1170;

	    
	    //Remove post types from portfolio posts
	    remove_post_type_support('portfolio','post-formats');
	    remove_post_type_support('portfolio','comments');
	    
	}
	add_action( 'init', 'nord_add_editor_styles', 10 );
}


//----------------------------------------------------------------------
// Remove Redux Framework NewsFlash
//----------------------------------------------------------------------
if ( ! class_exists( 'reduxNewsflash' ) ):
    class reduxNewsflash {
        public function __construct( $parent, $params ) {}
    }
endif;
//----------------------------------------------------------------------
// Remove Redux Framework Ads
//----------------------------------------------------------------------
add_filter( 'redux/inventory_options/aURL_filter', '__return_empty_string' );

